#!/bin/sh
# --------------------------------------------------------------------------------

COMPANY=alphakanal
AUDIOUNIT=Automat1

# remember entry point
# --------------------------------------------------------------------------------

ENTRYDIR=`pwd`
cd "`dirname "${0}"`"

# copy font
# --------------------------------------------------------------------------------

FONTS="${HOME}"/Library/Fonts
if [ ! -d "${FONTS}" ]
then
	echo "info : creating ${FONTS}"
	mkdir "${FONTS}"
fi

mv -f "${AUDIOUNIT}".component/Contents/Resources/automat.ttf "${FONTS}"
ERROR=$?
if (($ERROR))
then
	echo "info : font already installed!"
else
	echo "info : font successfully installed!"
	touch "${FONTS}"
fi

# check for user library
# --------------------------------------------------------------------------------

LIBRARY="${HOME}"/Library/Audio
if [ ! -d "${LIBRARY}" ]
then
	echo "error: missing ${LIBRARY}"
	exit -1
fi

# remove component
# --------------------------------------------------------------------------------

rm -rf "${LIBRARY}"/Plug-Ins/Components/"${AUDIOUNIT}".component
ERROR=$?
if (($ERROR))
then
	echo "error: no plugin found!"
else
	echo "info : plugin successfully removed!"
fi

# copy component
# --------------------------------------------------------------------------------

COMPONENTS="${LIBRARY}"/Plug-Ins/Components/
if [ ! -d "${COMPONENTS}" ]
then
	echo "info : creating ${COMPONENTS}"
	mkdir "${COMPONENTS}"
fi

cp -R -f "${AUDIOUNIT}".component "${COMPONENTS}"
ERROR=$?
if (($ERROR))
then
	echo "error: could not install the plugin!"
	exit $ERROR
else
	echo "info : plugin successfully installed!"
	touch "${COMPONENTS}"
fi

# copy presets
# --------------------------------------------------------------------------------

PRESETS="${LIBRARY}"/Presets/
if [ ! -d "${PRESETS}" ]
then
	echo "info : creating ${PRESETS}"
	mkdir "${PRESETS}"
fi

PRESETS="${PRESETS}${COMPANY}"/
if [ ! -d "${PRESETS}" ]
then
	echo "info : creating ${PRESETS}"
	mkdir "${PRESETS}"
fi

PRESETS="${PRESETS}${AUDIOUNIT}"/
if [ ! -d "${PRESETS}" ]
then
	echo "info : creating ${PRESETS}"
	mkdir "${PRESETS}"
fi

cp -R -f Presets/ "${PRESETS}"
ERROR=$?
if (($ERROR))
then
	echo "error: could not install the presets!"
	exit $ERROR
else
	echo "info : presets successfully installed!"
	touch "${PRESETS}"
fi

# show directories
# --------------------------------------------------------------------------------

# open "${COMPONENTS}"
# open "${PRESETS}"

# cleanup and bail out
# --------------------------------------------------------------------------------

cd "${ENTRYDIR}"
exit 0

# --------------------------------------------------------------------------------
